# Segment Wrapper
Useful wrapper around Segment SDK

## Description

This package adds an abstraction layer on top of [segment.com](https://segment.com/)'s [javascript library](https://segment.com/docs/sources/website/analytics.js/) with some useful integrations and fixes that could be used across Adevinta Spain:

- [x] Add `page` method that internally uses `track` but with the correct `referrer` property.
- [x] Monkey patch `track` native Segment method to send `marketingCloudVisitorId` inside `context.integrations`
- [x] Integrates DMP and send `ssf` correct value depeneding on user's consents.
- [x] Send `user.id` and `anonymousId` on every track.
- [x] Sync Facebook and Google pixels (if you provide the needed config)

## Usage

After adding your Segment snippet into your html, you'll need to include this package in order to be able to fire events.

`analytics` will be an object with the methods described [here](#events)

### Step 1: Copy the Snippet in your HTML

```html
<script>
  !function(){var analytics=window.analytics=window.analytics||[];if(!analytics.initialize)if(analytics.invoked)window.console&&console.error&&console.error("Segment snippet included twice.");else{analytics.invoked=!0;analytics.methods=["trackSubmit","trackClick","trackLink","trackForm","pageview","identify","reset","group","track","ready","alias","debug","page","once","off","on"];analytics.factory=function(t){return function(){var e=Array.prototype.slice.call(arguments);e.unshift(t);analytics.push(e);return analytics}};for(var t=0;t<analytics.methods.length;t++){var e=analytics.methods[t];analytics[e]=analytics.factory(e)}analytics.load=function(t,e){var n=document.createElement("script");n.type="text/javascript";n.async=!0;n.src="https://cdn.segment.com/analytics.js/v1/"+t+"/analytics.min.js";var a=document.getElementsByTagName("script")[0];a.parentNode.insertBefore(n,a);analytics._loadOptions=e};analytics.SNIPPET_VERSION="4.1.0";

  analytics.load("YOUR_WRITE_KEY");  // your write key must be set here
  }}();
</script>
````

### Step 2: Use

#### In your modern and beautiful JavaScript...

```js
import analytics from '@s-ui/segment-wrapper'
```

### In your monolithic JavaScript...

```js
// First load the UMD module.
<script src="https://unpkg.com/@s-ui/segment-wrapper/umd/index.js"></script>
<script>
  // Then trigger all the events you need referencing the right namespaced
  // object: `window.sui.analytics`. For more info see the "Events" section below.
  window.sui.analytics.identify('your user id', {});
  window.sui.analytics.track('your event', {});
  window.sui.analytics.reset();
</script>
```

### Step 3: Configure Segment Wrapper (optional)

You could put a special config in a the `window.__mpi` to change some behaviour of the wrapper. This config MUST somewhere before using the Segment Wrapper.

```js
  window.__mpi = {
    segmentWrapper: {
      googleAdsPixelId: '1054970353',
      facebookPixelId: '448176625351232'
    }
  }
```

## Events

### Track - [docs](https://segment.com/docs/spec/track/)

```js
analytics.track('Registered', {
  plan: 'Pro Annual',
  accountType: 'Facebook'
})
```

### Page
Internally uses `Track` but changes the `referrer` everytime is called.

```js
analytics.page('List Viewed', {
  property: 'HOUSE',
  transaction: 'SELL'
})
```

### Identify - [docs](https://segment.com/docs/spec/identify/)

```js
analytics.identify('97980cfea0067', {
  name: 'Peter Gibbons',
  email: 'peter@initech.com',
  plan: 'premium',
  logins: 5
})
```

### Reset - [docs](https://segment.com/docs/sources/website/analytics.js/#reset-logout)

```js
analytics.reset()
```
